Test program running on MAX32625MBED. Control through USB Serial commands using a terminal emulator such as teraterm or putty.

Dependencies:   MaximTinyTester MAX11410 CmdLine USBDevice

Revision:
54:ba810c1d6264
Parent:
52:d3fb6f1722bf
Child:
55:73d886c105f5
--- a/Test_Menu_MAX11410.cpp	Tue Feb 18 09:37:17 2020 +0000
+++ b/Test_Menu_MAX11410.cpp	Thu Feb 20 10:47:21 2020 +0000
@@ -328,8 +328,8 @@
 // CODE GENERATOR: MAX11410 Command Name = Configure_Voltage (MAX11410_AINP_SEL_enum_t ainp, MAX11410_AINN_SEL_enum_t ainn) --> uint8_t
 // CODE GENERATOR: no Menu item hint in description
 // CODE GENERATOR: MAX11410 Command Name = Read_All_Voltages (void) --> uint8_t
 // CODE GENERATOR: Menu item hint description Menu item '$'
 // CODE GENERATOR: Menu item '$' -- Menu item $
 // CODE GENERATOR: test menu case '$':
 // CODE GENERATOR:           helpString '$ -- Read_All_Voltages'
 // CODE GENERATOR:           CMD_ 'None'
@@ -648,18 +648,6 @@
         // case 'G'..'Z','g'..'z' are reserved for GPIO commands
         // case 'A'..'F','a'..'f' may be available if not claimed by bitstream commands
 // CODE GENERATOR: TODO1: prevent conflict ExternFunctionGPIOPinCommand with reserved case 'A'..'F','a'..'f'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'A' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'B' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'C' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'D' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'E' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'F' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'a' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'b' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'c' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'd' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'e' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'f' 'None'
 
     //
 }
@@ -907,18 +895,6 @@
 // CODE GENERATOR: TODO1: generate GPIO commands for LDAC, CLR, etc. based on device driver function names
         // case 'G'..'Z','g'..'z' are reserved for GPIO commands
         // case 'A'..'F','a'..'f' may be available if not claimed by bitstream commands
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'A' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'B' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'C' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'D' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'E' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'F' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'a' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'b' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'c' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'd' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'e' 'None'
-// CODE GENERATOR: ExternFunctionGPIOPinCommand 'f' 'None'
 
 // CODE GENERATOR: test menu
         // case '0'..'9','A'..'F','a'..'f' letters are reserved for bitstream commands
@@ -953,7 +929,7 @@
                     cmdLine.serial().printf("Init");
                     // call function Init
                     uint8_t result = g_MAX11410_device.Init();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="!", testMenuFirstCharHandler="None"
         } // end case '!'
@@ -984,12 +960,24 @@
                     // @Param[in]=''
                     // @Param[out]=''
                     // @Post='@post AINcode[0..10]: measurement result LSB code'
-                    // displayPost=''
+                    // displayPost='AINcode[0], AINcode[1], AINcode[2], AINcode[3], AINcode[4], AINcode[5], AINcode[6], AINcode[7], AINcode[8], AINcode[9], AINcode[10]'
                     // @Return='@return 1 on success; 0 on failure'
                     cmdLine.serial().printf("Read_All_Voltages");
                     // call function Read_All_Voltages
                     uint8_t result = g_MAX11410_device.Read_All_Voltages();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
+                    // Menu item '$' -> AINcode[0], AINcode[1], AINcode[2], AINcode[3], AINcode[4], AINcode[5], AINcode[6], AINcode[7], AINcode[8], AINcode[9], AINcode[10]
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[0]", g_MAX11410_device.AINcode[0]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[1]", g_MAX11410_device.AINcode[1]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[2]", g_MAX11410_device.AINcode[2]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[3]", g_MAX11410_device.AINcode[3]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[4]", g_MAX11410_device.AINcode[4]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[5]", g_MAX11410_device.AINcode[5]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[6]", g_MAX11410_device.AINcode[6]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[7]", g_MAX11410_device.AINcode[7]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[8]", g_MAX11410_device.AINcode[8]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[9]", g_MAX11410_device.AINcode[9]);
+                    cmdLine.serial().printf("%s=%d\r\n", "AINcode[10]", g_MAX11410_device.AINcode[10]);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="$", testMenuFirstCharHandler="None"
         } // end case '$'
@@ -1398,7 +1386,7 @@
                     cmdLine.serial().printf("Calibrate_Self_Offset_Gain");
                     // call function Calibrate_Self_Offset_Gain
                     uint8_t result = g_MAX11410_device.Calibrate_Self_Offset_Gain();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X0", testMenuFirstCharHandler="X"
                 } // end nested case 'X0'
@@ -1434,7 +1422,7 @@
                     cmdLine.serial().printf("Calibrate_PGA_Gain");
                     // call function Calibrate_PGA_Gain
                     uint8_t result = g_MAX11410_device.Calibrate_PGA_Gain();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X1", testMenuFirstCharHandler="X"
                 } // end nested case 'X1'
@@ -1470,7 +1458,7 @@
                     cmdLine.serial().printf("Calibrate_System_Offset_A");
                     // call function Calibrate_System_Offset_A
                     uint8_t result = g_MAX11410_device.Calibrate_System_Offset_A();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X4", testMenuFirstCharHandler="X"
                 } // end nested case 'X4'
@@ -1506,7 +1494,7 @@
                     cmdLine.serial().printf("Calibrate_System_Gain_A");
                     // call function Calibrate_System_Gain_A
                     uint8_t result = g_MAX11410_device.Calibrate_System_Gain_A();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X5", testMenuFirstCharHandler="X"
                 } // end nested case 'X5'
@@ -1542,7 +1530,7 @@
                     cmdLine.serial().printf("Calibrate_System_Offset_B");
                     // call function Calibrate_System_Offset_B
                     uint8_t result = g_MAX11410_device.Calibrate_System_Offset_B();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X6", testMenuFirstCharHandler="X"
                 } // end nested case 'X6'
@@ -1578,7 +1566,7 @@
                     cmdLine.serial().printf("Calibrate_System_Gain_B");
                     // call function Calibrate_System_Gain_B
                     uint8_t result = g_MAX11410_device.Calibrate_System_Gain_B();
-                    cmdLine.serial().printf(" =%d", result);
+                    cmdLine.serial().printf(" =%d\r\n", result);
                     return true; // command handled by MAX11410
 // CODE GENERATOR: bottom of loop: testMenuCommand="X7", testMenuFirstCharHandler="X"
                 } // end nested case 'X7'
@@ -328,8 +328,8 @@
 // CODE GENERATOR: no Menu item hint in description
 // CODE GENERATOR: MAX11410 Command Name = Read_All_Voltages (void) --> uint8_t
-// CODE GENERATOR: Menu item hint description Menu item '$'
-// CODE GENERATOR: Menu item '$' -- Menu item $
+// CODE GENERATOR: Menu item hint description Menu item '$' -> AINcode[0], AINcode[1], AINcode[2], AINcode[3], AINcode[4], AINcode[5], AINcode[6], AINcode[7], AINcode[8], AINcode[9], AINcode[10]
+// CODE GENERATOR: Menu item '$' -> AINcode[0], AINcode[1], AINcode[2], AINcode[3], AINcode[4], AINcode[5], AINcode[6], AINcode[7], AINcode[8], AINcode[9], AINcode[10] -- Menu item $
 // CODE GENERATOR: test menu case '$':
 // CODE GENERATOR:           helpString '$ -- Read_All_Voltages'